<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/mainmenu.cpp" line="57"/>
        <source>Play</source>
        <translation>Jouer</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="61"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="65"/>
        <source>Credits</source>
        <translation>Crédits</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="69"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../menu/mainmenu.cpp" line="77"/>
        <source>Settings</source>
        <translation>Options</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="31"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../menu/confirmationmenu.cpp" line="32"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>PROGRAMMING BY</source>
        <translation type="vanished">PROGRAMMATION</translation>
    </message>
    <message>
        <source>GRAPHICS BY</source>
        <translation type="vanished">GRAPHISMES</translation>
    </message>
    <message>
        <source>RACE TRACKS BY</source>
        <translation type="vanished">CIRCUITS</translation>
    </message>
    <message>
        <source>CONTRIBUTORS</source>
        <translation type="vanished">CONTRIBUTEURS</translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="40"/>
        <source>PROGRAMMING</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="42"/>
        <source>GRAPHICS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="44"/>
        <source>LEVEL DESIGN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="46"/>
        <source>TRANSLATIONS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="48"/>
        <source>PATCHES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/credits.cpp" line="50"/>
        <source>SPECIAL THANKS</source>
        <translation>REMERCIEMENTS PARTICULIERS</translation>
    </message>
    <message>
        <location filename="../menu/help.cpp" line="31"/>
        <source>GAME GOAL

You are racing against eleven
computer players.

Your best position will be
the next start position.

Finish in TOP-6 to unlock
a new race track!

CONTROLS FOR PLAYER 1

Turn left  : Left
Turn right : Right
Accelerate : Up / RIGHT SHIFT
Brake      : Down / RIGHT CTRL

CONTROLS FOR PLAYER 2

Turn left  : A
Turn right : D
Accelerate : W / LEFT SHIFT
Brake      : S / LEFT CTRL

Quit       : ESC/Q
Pause      : P</source>
        <translation>OBJECTIF DU JEU

Vous concourrez contre 11 véhicules
joués par l&apos;ordinateur.

Votre meilleur position deviendra votre
prochaine position de départ.

Finissez dans le TOP 6 pour débloquer
une nouvelle piste de course !

CONTRÔLES POUR LE JOUEUR 1

Tourner à gauche : Gauche
Tourner à droite : Droite
Accélérer        : Haut / Maj Droite
Freiner          : Bas / Ctrl Droite

Quitter          : Échap / Q
Pause            : P</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="49"/>
        <source>Press a key..</source>
        <translation>Appuyez sur une touche...</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="89"/>
        <source>Player One Accelerate</source>
        <translation>Joueur 1 Accélérer</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="98"/>
        <source>Player One Brake</source>
        <translation>Joueur 1 Freiner</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="107"/>
        <source>Player One Turn Left</source>
        <translation>Joueur 1 Tourner à gauche</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="116"/>
        <source>Player One Turn Right</source>
        <translation>Joueur 1 Tourner à droite</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="138"/>
        <source>Player Two Accelerate</source>
        <translation>Joueur 2 Accélérer</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="147"/>
        <source>Player Two Brake</source>
        <translation>Joueur 2 Freiner</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="156"/>
        <source>Player Two Turn Left</source>
        <translation>Joueur 2 Tourner à gauche</translation>
    </message>
    <message>
        <location filename="../menu/keyconfigmenu.cpp" line="165"/>
        <source>Player Two Turn Right</source>
        <translation>Joueur 2 Tourner à droite</translation>
    </message>
    <message>
        <source>At least OpenGL ES 2.0 is required!</source>
        <translation type="vanished">OpenGL ES 2.0 ou supérieur est nécessaire !</translation>
    </message>
    <message>
        <source>Cannot start Dust Racing 2D</source>
        <translation type="vanished">Dust Racing 2D ne peut pas démarrer</translation>
    </message>
    <message>
        <source>At least OpenGL 3.0 is required!</source>
        <translation type="vanished">OpenGL 3.0 ou supérieur est nécessaire !</translation>
    </message>
    <message>
        <source>At least OpenGL 2.1 is required!</source>
        <translation type="vanished">OpenGL 2.1 ou supérieur est nécessaire !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="76"/>
        <source>New race record!</source>
        <translation>Nouveau record de la course !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="69"/>
        <source>New lap record!</source>
        <translation>Nouveau record par tour !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="347"/>
        <source>The Time Trial has ended!</source>
        <translation>Le Contre la montre est terminé !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="351"/>
        <source>The winner has finished!</source>
        <translation>Le vainqueur est arrivé !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="376"/>
        <source>Pit stop!</source>
        <translation>Arrêt au stand !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="569"/>
        <source>A new best pos!</source>
        <translation>Une nouvelle meilleure position !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="579"/>
        <source>A new track unlocked!</source>
        <translation>Un nouveau circuit a été débloqué !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="583"/>
        <source>Better luck next time..</source>
        <translation>La prochaine fois sera la bonne...</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="626"/>
        <source>You must stay on track!</source>
        <translation>Vous devez rester sur la piste !</translation>
    </message>
    <message>
        <location filename="../race.cpp" line="630"/>
        <source>Watch your tires!</source>
        <translation>Attention à vos roues !</translation>
    </message>
    <message>
        <location filename="../menu/resolutionmenu.cpp" line="115"/>
        <source>Restart to change the resolution.</source>
        <translation>Redémarrez pour changer la résolution.</translation>
    </message>
    <message>
        <source>Native resolution</source>
        <translation type="vanished">Résolution native</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="78"/>
        <source>Reset best positions?</source>
        <translation>Réinitialiser les meilleures positions ?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="89"/>
        <source>Reset record times?</source>
        <translation>Réinitialiser les temps records ?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="101"/>
        <source>Reset unlocked tracks?</source>
        <translation>Réinitialiser les circuits débloqués ?</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="200"/>
        <source>Game mode &gt;</source>
        <translation>Mode de jeu &gt;</translation>
    </message>
    <message>
        <source>Lap Count &gt;</source>
        <translation type="vanished">Nombre de tours &gt;</translation>
    </message>
    <message>
        <source>Difficulty &gt;</source>
        <translation type="vanished">Difficulté</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="204"/>
        <source>Sounds &gt;</source>
        <translation>Audio &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="208"/>
        <source>GFX &gt;</source>
        <translation>Graphismes &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="212"/>
        <source>Controls &gt;</source>
        <translation>Contrôles &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="216"/>
        <source>Reset &gt;</source>
        <translation>Réinitialiser &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="236"/>
        <source>30 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="246"/>
        <source>60 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="277"/>
        <source>Two player race</source>
        <translation>Course à deux joueurs</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="286"/>
        <source>One player race</source>
        <translation>Course à un joueur</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="295"/>
        <source>Time Trial</source>
        <translation>Contre la montre</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="304"/>
        <source>Duel</source>
        <translation>Duel</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="328"/>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="337"/>
        <source>Horizontal</source>
        <translation>Horizontale</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="42"/>
        <source>Easy</source>
        <translation>Aisé</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="52"/>
        <source>Medium</source>
        <translation>Intermédiaire</translation>
    </message>
    <message>
        <location filename="../menu/difficultymenu.cpp" line="62"/>
        <source>Hard</source>
        <translation>Difficile</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="358"/>
        <source>Full screen resolution &gt;</source>
        <translation>Résolution plein écran &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="362"/>
        <source>Windowed resolution &gt;</source>
        <translation>Résolution en mode fenêtré &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="366"/>
        <source>FPS &gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="370"/>
        <source>Split type &gt;</source>
        <translation>Séparation d&apos;écran &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="374"/>
        <source>VSync &gt;</source>
        <translation>VSync &gt;</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="393"/>
        <location filename="../menu/vsyncmenu.cpp" line="99"/>
        <source>Off</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="405"/>
        <location filename="../menu/vsyncmenu.cpp" line="103"/>
        <source>On</source>
        <translation>Activé</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="435"/>
        <source>Reset record times</source>
        <translation>Réinitialiser les temps records</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="439"/>
        <source>Reset best positions</source>
        <translation>Réinitialiser les meilleures positions</translation>
    </message>
    <message>
        <location filename="../menu/settingsmenu.cpp" line="443"/>
        <source>Reset unlocked tracks</source>
        <translation>Réinitialiser les circuits débloqués</translation>
    </message>
    <message>
        <location filename="../startlights.cpp" line="135"/>
        <source>GO!!!</source>
        <translation>GO !!!</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="52"/>
        <source>---</source>
        <translation>---</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="53"/>
        <source>1st</source>
        <translation>1er</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="54"/>
        <source>2nd</source>
        <translation>2ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="55"/>
        <source>3rd</source>
        <translation>3ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="56"/>
        <source>4th</source>
        <translation>4ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="57"/>
        <source>5th</source>
        <translation>5ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="58"/>
        <source>6th</source>
        <translation>6ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="59"/>
        <source>7th</source>
        <translation>7ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="60"/>
        <source>8th</source>
        <translation>8ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="61"/>
        <source>9th</source>
        <translation>9ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="62"/>
        <source>10th</source>
        <translation>10ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="63"/>
        <source>11th</source>
        <translation>11ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="64"/>
        <source>12th</source>
        <translation>12ème</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="185"/>
        <source> LAP:</source>
        <translation> TOUR:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="202"/>
        <source> POS:</source>
        <extracomment>Position/rank</extracomment>
        <translation> POS:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAP</source>
        <translation>TOUR</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="210"/>
        <source>LAPS</source>
        <translation>TOURS</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="247"/>
        <source> KM/H</source>
        <translation> KM/H</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="260"/>
        <source>LAP:</source>
        <translation>TOUR:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="306"/>
        <source>L:</source>
        <extracomment>Last lap time</extracomment>
        <translation>T:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="326"/>
        <source>R:</source>
        <extracomment>Lap record time</extracomment>
        <translation>C:</translation>
    </message>
    <message>
        <location filename="../timingoverlay.cpp" line="347"/>
        <source>TOT:</source>
        <extracomment>Total race time</extracomment>
        <translation>TOTAL:</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="266"/>
        <source>       Laps: </source>
        <translation>        Tours : </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="273"/>
        <source>     Length: </source>
        <translation>     Longueur : </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="311"/>
        <source>Finish previous track in TOP-6 to unlock!</source>
        <extracomment>Try to keep the translation as short as possible.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="316"/>
        <source>Unlock it in one/two player race!</source>
        <extracomment>&quot;it&quot; = a locked track. Try to keep the translation as short as possible.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> m</source>
        <translation type="vanished"> m</translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="280"/>
        <source> Lap Record: </source>
        <translation>  Record par tour : </translation>
    </message>
    <message>
        <location filename="../menu/trackselectionmenu.cpp" line="287"/>
        <source>Race Record: </source>
        <translation>Record de la course : </translation>
    </message>
    <message>
        <location filename="../menu/vsyncmenu.cpp" line="75"/>
        <source>Restart to change VSync setting.</source>
        <translation>Rédémarrez pour changer l&apos;option VSync.</translation>
    </message>
    <message>
        <location filename="../menu/lapcountmenu.cpp" line="84"/>
        <source>Choose lap count</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
